@@ -1,4 +1,4 @@
-// $Id: BackupOptDlg.cpp,v 1.11.4.1 2004/04/12 17:04:25 binner Exp $
+// $Id: BackupOptDlg.cpp 294381 2004-03-08 10:49:16Z waba $
 //
 // KDat - a tar-based DAT archiver
 // Copyright (C) 1998-2000  Sean Vyain, svyain@mail.tds.net
@@ -19,11 +19,11 @@
 // Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
 #include <qlayout.h>
-
-#include <kapplication.h>
 #include <kpushbutton.h>
 #include <kstdguiitem.h>
 
+#include <kapplication.h>
+
 #include "BackupOptDlg.h"
 #include "BackupProfileWidget.h"
 #include <klocale.h>
@@ -41,10 +41,10 @@ BackupOptDlg::BackupOptDlg( BackupProfile* backupProfile, QWidget* parent, const
     _profile = new BackupProfileWidget( this );
     _profile->setBackupProfile( backupProfile );
 
-    QPushButton* ok = new KPushButton( KStdGuiItem::ok(), this );
+    KPushButton* ok = new KPushButton( KStdGuiItem::ok(), this );
     ok->setFixedSize( 80, ok->sizeHint().height() );
     connect( ok, SIGNAL( clicked() ), this, SLOT( accept() ) );
-    QPushButton* cancel = new KPushButton( KStdGuiItem::cancel(), this );
+    KPushButton* cancel = new KPushButton( KStdGuiItem::cancel(), this );
     cancel->setFixedSize( 80, ok->sizeHint().height() );
     connect( cancel, SIGNAL( clicked() ), this, SLOT( reject() ) );
 
