@@ -16,8 +16,8 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-#ifndef _KDat_h_
-#define _KDat_h_
+#ifndef KDat_h
+#define KDat_h
 
 #include <kmainwindow.h>
 #include <kdialog.h>
