@@ -1,5 +1,6 @@
 // KDat - a tar-based DAT archiver
-// Copyright (C) 1998  Sean Vyain, svyain@mail.tds.net
+// Copyright (C) 1998-2000  Sean Vyain, svyain@mail.tds.net
+// Copyright (C) 2001-2002  Lawrence Widman, kdat@cardiothink.com
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -399,7 +400,7 @@ public:
      * Get a list of all the selected ranges for the subtree rooted at this
      * node.
      */
-    virtual const QList<Range>& getRanges() = 0;
+    virtual const QPtrList<Range>& getRanges() = 0;
 
     /**
      * Determine whether the node is an instance of the given node type.
@@ -441,7 +442,7 @@ public:
      * Get a list of all the selected ranges for the subtree rooted at this
      * node.
      */
-    virtual const QList<Range>& getRanges();
+    virtual const QPtrList<Range>& getRanges();
 
     /**
      * Select/deselect this node and all of its children.
@@ -512,7 +513,7 @@ public:
      * Get a list of all the selected ranges for the subtree rooted at this
      * node.
      */
-    virtual const QList<Range>& getRanges();
+    virtual const QPtrList<Range>& getRanges();
 
     /**
      * Select/deselect this node and all of its children.
@@ -592,7 +593,7 @@ public:
      * Get a list of all the selected ranges for the subtree rooted at this
      * node.
      */
-    virtual const QList<Range>& getRanges();
+    virtual const QPtrList<Range>& getRanges();
 
     /**
      * Select/deselect this node and all of its children.
