@@ -1,5 +1,4 @@
-/* debInterface.h
-**
+/*
 ** Copyright (C) 1999,2000 Toivo Pedaste <toivo@ucs.uwa.edu.au>
 **
 */
@@ -75,7 +74,7 @@ public:
 
   virtual void listInstalledPackages(QPtrList<packageInfo> *pki);
 
-  virtual QStringList FindFile(const QString &name);
+  virtual QStringList FindFile(const QString &name, bool seachAll=false);
   virtual bool parseName(const QString &name, QString *n, QString *v);
 
   virtual packageInfo* collectInfo(QStringList &ln,  pkgInterface *pkgInt = 0);
