@@ -1,7 +1,5 @@
-/* fbsdInterface.cc
-**
+/*
 ** Copyright (C) 2000 by Alex Hayward <xelah@xelah.com>
-**
 */
 
 
@@ -345,7 +343,7 @@ QString fbsdInterface::uninstall(int uninstallFlags, QPtrList<packageInfo> *p, b
   return doUninstall( uninstallFlags, packs, test);
 }
 
-QStringList fbsdInterface::FindFile(const QString &) {
+QStringList fbsdInterface::FindFile(const QString &, bool) {
   QStringList tmp;
   return tmp;
 }
@@ -402,6 +400,7 @@ void fbsdInterface::setAvail(LcacheObj *slist) {
   if (!ports_found) {
     // Try the standard ports tree locations.
     bsdPortsIndexItem::processFile("/usr/ports/INDEX", false, "/usr/ports"); // FreeBSD/OpenBSD
+    bsdPortsIndexItem::processFile("/usr/ports/INDEX-5", false, "/usr/ports"); // FreeBSD/OpenBSD
     bsdPortsIndexItem::processFile("/usr/opt/INDEX", false, "/usr/opt");  // NetBSD
   }
 }
@@ -424,7 +423,7 @@ void fbsdInterface::listPackages(QPtrList<packageInfo> *pki) {
 	a->setAutoDelete(TRUE);
 
 	addNV(a, scan->name);
-	a->insert("summary", new QString(scan->name));
+	a->insert("summary", new QString(scan->comment));
 	a->insert("maintainer", new QString(scan->maint));
 
 	insertGroups(a,scan->cats);
@@ -672,7 +671,7 @@ bsdPortsIndexItem::bsdPortsIndexItem(char *desc, bool binaries, QString dname) :
     desc++;
   }
 
-  if (itemno != 8 && itemno != 9) {
+  if (itemno < 7 || itemno > 13) {
      KpMsgE(i18n("Warning: invalid INDEX file entry for %1").arg(name),FALSE);
   }
     name_hash = calc_hash4(name);
