@@ -1,5 +1,4 @@
-/* kissInterface.cpp
-**
+/*
 ** Copyright (C) 1999,2000 Toivo Pedaste <toivo@ucs.uwa.edu.au>
 **
 */
@@ -383,7 +382,7 @@ QString KISS::doInstall(int, QString packs, bool &)
 
 //////////////////////////////////////////////////////////////////////////////
 //////////////////////////////////////////////////////////////////////////////
-QStringList KISS::FindFile(const QString &name)
+QStringList KISS::FindFile(const QString &name, bool)
 {
   QString s = "kiss -p ";
   s += name;
