@@ -1,5 +1,4 @@
-/* kpackage.cpp
-**
+/*
 ** Copyright (C) 1999,2000 Toivo Pedaste <toivo@ucs.uwa.edu.au>
 **
 // Author: Damyan Pepper
@@ -68,7 +67,7 @@ extern Opts *opts;
 KPKG::KPKG(KConfig *_config)
   : KMainWindow(0)
 {
-  kpackage = new KPACKAGE(_config,this);
+  kpackage = new KPACKAGE(_config, this);
   setCentralWidget(kpackage);
 
   config =  kapp->config();
@@ -116,10 +115,10 @@ void KPKG::setupMenu()
   (void) KStdAction::quit(kpackage, SLOT(fileQuit()),
 			  actionCollection());
 
-  pack_prev = KStdAction::back(kpackage->management, SLOT(previous()),
+  pack_prev = KStdAction::back(kpackage->management->treeList, SLOT(previous()),
 			       actionCollection(),"pack_prev");
 
-  pack_next = KStdAction::forward(kpackage->management, SLOT(next()),
+  pack_next = KStdAction::forward(kpackage->management->treeList, SLOT(next()),
 				  actionCollection(),"pack_next");
 
   (void) (new KAction( i18n("&Expand Tree"), "ftout",
@@ -258,8 +257,8 @@ void KPKG::writeSettings(){
 
   recent->saveEntries( config );
 
-  kpackage->management->writeTreePos();
-  kpackage->management->writeTreeType();
+  kpackage->management->treeList->writeTreePos();
+  kpackage->management->treeList->writeTreeType();
 
   config->sync();
 }
@@ -432,22 +431,22 @@ void KPACKAGE::fileOpen()		// file->quit selected from menu
 
 void KPACKAGE::clearMarked()
 {
-  management->clearMarked(management->treeList->firstChild());
+  management->treeList->clearMarked(management->treeList->firstChild());
 }
 
 void KPACKAGE::markAll()
 {
-  management->markAll(management->treeList->firstChild());
+  management->treeList->markAll(management->treeList->firstChild());
 }
 
 void KPACKAGE::expandTree()
 {
-  management->expandTree(management->treeList);
+  management->treeList->expandTree(management->treeList);
 }
 
 void KPACKAGE::collapseTree()
 {
-  management->collapseTree(management->treeList);
+  management->treeList->collapseTree(management->treeList);
 }
 
 pkgInterface *KPACKAGE::pkType(const QString &fname)
@@ -534,7 +533,7 @@ void KPACKAGE::openNetFiles (QStringList urls, bool install )
       }
     } else {
       if (pk) {
-	KPLVItem *pt = pk->item;
+	KpTreeListItem *pt = pk->item;
 	// NOT the best place for this CODE
 	kpackage->management->tabChanged(Opts::ALL);
 	if (pt)
