@@ -1,5 +1,4 @@
-/* kpackage.h
-**
+/*
 ** Copyright (C) 1999,2000 Toivo Pedaste <toivo@ucs.uwa.edu.au>
 **
 ** This is the main widget for kpackage
@@ -67,7 +66,7 @@ class KPACKAGE : public QWidget
 
   ///////////// METHODS ------------------------------------------------------
 public:
-  KPACKAGE(KConfig *_config, QWidget *parent=0);
+  KPACKAGE(KConfig *_config, QWidget *parent);
   // Constructor
 
   ~KPACKAGE();
@@ -185,6 +184,9 @@ public:
   KURL save_url;
   // save the URL entered
 
+  FindF *findialog;
+  // find file dialog
+
 private:
   int mode;
   // Widget mode
@@ -206,8 +208,6 @@ private:
   Search *srchdialog;
   // find package dialog
 
-  FindF *findialog;
-  // find file dialog
 };
 
 //////////////////////////////////////////////////////////////////////////////
