@@ -1,15 +1,44 @@
-///////////////////////////////////////////////////////////////////////////
-// $Id: managementWidget.cpp,v 1.60 2002/09/11 15:04:25 toivo Exp $
-// File  : managementWidget.cpp
+/*
+** Copyright (C) 1999,2000 Toivo Pedaste <toivo@ucs.uwa.edu.au>
+**
 // Author: Damyan Pepper
 // Author: Toivo Pedaste
 //
 // See managementWidget.h for more information
+*/
+
+/*
+** This program is free software; you can redistribute it and/or modify
+** it under the terms of the GNU General Public License as published by
+** the Free Software Foundation; either version 2 of the License, or
+** (at your option) any later version.
+**
+** This program is distributed in the hope that it will be useful,
+** but WITHOUT ANY WARRANTY; without even the implied warranty of
+** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+** GNU General Public License for more details.
+**
+** You should have received a copy of the GNU General Public License
+** along with this program in a file called COPYING; if not, write to
+** the Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
+** MA 02111-1307, USA.
+*/
+
+/*
+** Bug reports and questions can be sent to kde-devel@kde.org
+*/
+
 
 #include <qsplitter.h>
-#include <qptrstack.h>
+#include <qtoolbutton.h>
 
 #include <klocale.h>
+#include <kdebug.h>
+#include <klistviewsearchline.h>
+#include <kaction.h>
+#include <kstdaction.h>
+#include <ktoolbar.h>
+#include <kiconloader.h>
 
 // kpackage.headers
 #include "kpackage.h"
@@ -23,16 +52,33 @@
 
 extern Opts *opts;
 
+KpListViewSearchLine::KpListViewSearchLine(QWidget *parent, KpTreeList *listView)  
+  :KListViewSearchLine(parent, listView)
+{
+  list = listView;
+}
+
+KpListViewSearchLine::~KpListViewSearchLine()
+{
+}
+
+void KpListViewSearchLine::updateSearch(const QString &s)
+{
+    list->expand();
+    KListViewSearchLine::updateSearch(s);
+    KListViewSearchLine::updateSearch(s); // Yes both are needed
+    list->sweep(false);
+}
+
+
 // constructor -- initialise variables
 managementWidget::managementWidget(QWidget *parent)
   : QFrame(parent)
 {
-  install_action=0;
-  uninstall_action=0;
-  package=0;
+  install_action = 0;
+  uninstall_action = 0;
 
   allPackages  = new QPtrList<packageInfo>;
-  QPtrStack<QString> stack();
 
   tType[0] = i18n("Installed");
   tType[1] = i18n("Updated");
@@ -42,7 +88,11 @@ managementWidget::managementWidget(QWidget *parent)
   dirInstPackages = new QDict<packageInfo>(7717);
   dirUninstPackages = new QDict<packageInfo>(7717);
   dirInfoPackages = new QDict<packageInfo>(7717);
+
   setupWidgets();
+
+  connect(treeList,SIGNAL(updateMarked()), 
+	  this, SLOT( checkMarked()));
 }
 
 managementWidget::~managementWidget()
@@ -73,39 +123,38 @@ void managementWidget::setupWidgets()
 
   QTabBar *ltab = new QTabBar(leftpanel);
 
-  readTreeType();
-  treeList = new KPQListView(leftpanel);
+  treeList = new KpTreeList(leftpanel);
 
-  treeList->setFrameStyle(QFrame::Panel|QFrame::Sunken);
-  treeList->setLineWidth(2);
-  treeList->setItemMargin(2);
-  treeList->addColumn(i18n("Package"));
-  treeList->setColumnWidthMode(0,QListView::Manual);
-  treeList->addColumn(i18n("Mark"));
-  treeList->setColumnWidthMode(1,QListView::Manual);
-  treeList->addColumn(i18n("Size"));
-  treeList->setColumnWidthMode(2,QListView::Manual);
-  treeList->addColumn(i18n("Version"));
-  treeList->setColumnWidthMode(3,QListView::Manual);
-  treeList->addColumn(i18n("Old Version"));
-  treeList->setColumnWidthMode(4,QListView::Manual);
-  //  treeList->setAllColumnsShowFocus(TRUE);
-  treeList->setRootIsDecorated(TRUE);
-  readTreePos();
-  treeList->update();
-  treeList->show();
 
   for (int i = 0; i < 4; i++) {
     QTab *t = new QTab();
     t->setText( tType[i] );
     ltab->addTab(t);
   }
+  // Quick Search Bar
+  searchToolBar = new KToolBar( leftpanel, "search toolbar");
+
+  QToolButton *clearSearch = new QToolButton(searchToolBar);
+  clearSearch->setTextLabel(i18n("Clear Search"), true);
+  clearSearch->setIconSet(SmallIconSet(QApplication::reverseLayout() ? "clear_left"
+                                            : "locationbar_erase"));
+  (void) new QLabel(i18n("Search: "),searchToolBar);
+
+  searchLine = new KpListViewSearchLine(searchToolBar, treeList);
+  //  searchLine->setKeepParentsVisible(false);
+  connect( clearSearch, SIGNAL( pressed() ), searchLine, SLOT( clear() ));
+
+  QValueList<int> clist;  clist.append(0);  clist.append(2);
+  searchLine->setSearchColumns(clist);
+
+  searchToolBar->setStretchableWidget( searchLine );
+  connect( treeList, SIGNAL( cleared() ), searchLine, SLOT( clear() ));
+
   connect(ltab,SIGNAL(selected (int)),SLOT(tabChanged(int)));
-  ltab->setCurrentTab(treeType);
+  ltab->setCurrentTab(treeList->treeType);
 
-
-  //  ltab->tabBar.setCurrentTab(treeType);
   leftbox->addWidget(ltab,10);
+  leftbox->addWidget(searchToolBar,10);
   leftbox->addWidget(treeList,10);
 
   leftbox->addStretch();
@@ -113,11 +162,11 @@ void managementWidget::setupWidgets()
   lbuttons = new QBoxLayout(QBoxLayout::LeftToRight);
 
   luinstButton = new QPushButton(i18n("Uninstall Marked"),leftpanel);
-  luinstButton->setEnabled(TRUE);
+  luinstButton->setEnabled(FALSE);
   connect(luinstButton,SIGNAL(clicked()),
 	  SLOT(uninstallMultClicked()));
   linstButton = new QPushButton(i18n("Install Marked"),leftpanel);
-  linstButton->setEnabled(TRUE);
+  linstButton->setEnabled(FALSE);
   connect(linstButton,SIGNAL(clicked()),
 	  SLOT(installMultClicked()));
 
@@ -136,10 +185,8 @@ void managementWidget::setupWidgets()
   rightbox = new QBoxLayout(rightpanel,QBoxLayout::TopToBottom);
 
   packageDisplay = new packageDisplayWidget(rightpanel);
-  //  packageDisplay->setFrameStyle(QFrame::Panel|QFrame::Sunken);
-  //  packageDisplay->setLineWidth(2);
-  connect(this, SIGNAL(changePackage(packageInfo *)),
-	  packageDisplay, SLOT(changePackage(packageInfo *)));
+  //  connect(this, SIGNAL(changePackage(packageInfo *)),
+  //  packageDisplay, SLOT(changePackage(packageInfo *)));
 
   rbuttons = new QBoxLayout(QBoxLayout::LeftToRight);
 
@@ -161,8 +208,13 @@ void managementWidget::setupWidgets()
   rbuttons->addWidget(instButton,1);
   rbuttons->addWidget(uinstButton,1);
   rbuttons->addStretch(1);
+
 }
 
+////////////////////////////////////////////////////////////////
+
+
+
 ////////////////////////////////////////////////////////////////
 void managementWidget::writePSeparator()
 {
@@ -188,44 +240,36 @@ void managementWidget::readPSeparator()
   vPan->setSizes(size);
 }
 
-////////////////////////////////////////////////////////////////
-void managementWidget::writeTreeType()
-{
-  KConfig *config = kapp->config();
-
-  config->setGroup("Kpackage");
-
-  config->writeEntry("Package_Display",treeType);
-}
-
-void managementWidget::readTreeType()
-{
-  KConfig *config = kapp->config();
-
-  config->setGroup("Kpackage");
-
-  treeType = config->readNumEntry("Package_Display",3);
-
-}
-
 ///////////////////////////////////////////////////////////////////
+void managementWidget::setupMultButton(int &cntInstall, int &cntUnInstall)
+{
+  if (cntInstall)
+    linstButton->setEnabled(true);
+  else
+    linstButton->setEnabled(false);
+
+  if (cntUnInstall)
+    luinstButton->setEnabled(true);
+  else
+    luinstButton->setEnabled(false);
+}
+
 void managementWidget::setupInstButton()
 {
   bool u,i;
-  if (!package)
-  {
+
+  packageInfo *package = packageDisplay->package;
+
+  if (!package) {
     i = false;
     u = false;
-  }
-  else
-  {
-    if (package->interface->noFetch || !package->getFilename().isEmpty() ) {
+  } else {
+    if (package->isFetchable() ) {
       instButton->setText(i18n("Install"));
     } else {
       instButton->setText(i18n("Fetch"));
     }
-    if (package->packageState != packageInfo::INSTALLED &&
-        !package->getProperty("filename").isNull() ) {
+    if (package->isInstallable() ) {
 
       i = true;
       u = false;
@@ -240,7 +284,7 @@ void managementWidget::setupInstButton()
 
   uinstButton->setEnabled(u);
   if (uninstall_action)
-     uninstall_action->setEnabled(u);
+    uninstall_action->setEnabled(u);
 }
 
 void managementWidget::arrangeWidgets()
@@ -250,8 +294,8 @@ void managementWidget::arrangeWidgets()
 
 void managementWidget::tabChanged(int tab)
 {
-  treeType = tab;
-  sweep();
+   treeList->treeType = tab;
+   searchLine->updateSearch();
 }
 
 
@@ -261,7 +305,7 @@ void managementWidget::collectData(bool refresh)
   int i;
 
   if (!refresh && allPackages) {
-    sweep();
+    treeList->sweep(true);
     return; // if refresh not required already initialised
   }
 
@@ -275,7 +319,7 @@ void managementWidget::collectData(bool refresh)
   connect(treeList, SIGNAL(selectionChanged(QListViewItem *)),
 	  SLOT(packageHighlighted(QListViewItem *)));
 
-  packageDisplay->noPackage();
+  packageDisplay->changePackage(0);
 
   // Delete old list if necessary
   if(allPackages) {
@@ -328,55 +372,24 @@ void managementWidget::rebuildListTree()
       }
       n++;
     }
+  treeList->sweep(true);
   treeList->show();		// show the list tree
-  sweep();
 
   treeList->setSorting(0);
 
   kpackage->setPercent(100);	// set the progress
   kpackage->setStatus("");
+
+  checkMarked();
 }
 
 // A package has been highlighted in the list tree
 void managementWidget::packageHighlighted(QListViewItem *item)
 {
-
-  KPLVItem *sel = (KPLVItem *)item;
-
-  if (!sel || sel->childCount()) {
-    emit changePackage(0);
-    package = 0;
-  } else if (sel) {
-
-    if (!notPress) {
-      int n = stack.at();
-      int num = stack.count();
-      for (int i = num - 1; i >= n; i--) {
-	stack.remove(i);
-      }
-      kpkg->disableNext();
-    }
-
-    // Disable the tree list while we do this
-    treeList->setEnabled(FALSE);
-    // Tell everything that is interested to change packages
-    emit changePackage(sel->info);
-
-    // Keep copy of the package
-    package = sel->info;
-
-    // Re-enable the treeList and uninstall button
-    treeList->setEnabled(TRUE);
-    treeList->setFocus();
-
-    if (!notPress) {
-      stack.append(sel);
-    }
-  }
+ 
+  treeList->packageHighlighted(item, packageDisplay);
   setupInstButton();
 
-  notPress = false;
-  // Update the status bar
   kpackage->setPercent(100);
 }
 
@@ -388,32 +401,41 @@ void managementWidget::installSingleClicked()
   int result;
   QPtrList<packageInfo> plist;
 
+  packageInfo *package = packageDisplay->package;
+
   if (package) {
     QString filename = package->getFilename();
-    kdDebug() << "File=" << filename << "\n";
+    kdDebug() << "File=" << filename  <<"\n";
     pkgInterface *interface = package->interface;
     if (interface->noFetch || !filename.isEmpty()) {
       plist.append(package);
       interface->installation->setup(&plist, interface->head);
       result = interface->installation->exec();
 
-      if(result == QDialog::Accepted) { // execute it
+      if (interface->installation->result() == QDialog::Accepted ||
+	  interface->installation->modified) { 
 	// it was accepted, so the package has been installed
 	packageInfo *inf;
 	for (inf = plist.first(); inf != 0; inf = plist.next()) {
 	  updatePackage(inf,TRUE);
 	}
 
-	emit changePackage(0); // change package to no package
-	package = 0;
-        setupInstButton();
+	if (treeList->currentItem()) {
+	  KpTreeListItem *p = treeList->currentItem();
+	  packageDisplay->changePackage(p->info);
+	} else {
+	  packageDisplay->changePackage(0); // change package to no package
+	}
+	setupInstButton();	  
       }
+
+      //      kdDebug() << "Result=" << result <<"\n";
     } else {
       QString url = package->getUrl();
       if (!url.isEmpty()) {
 	QString s = kpackage->fetchNetFile(url);
 	if (!s.isEmpty()) {
-	  emit changePackage(package);
+	  packageDisplay->changePackage(package);
 	  setupInstButton();
 	}
       } else {
@@ -422,18 +444,21 @@ void managementWidget::installSingleClicked()
     }
   }
   kpackage->setPercent(100);
+
+  checkMarked();
 }
 
 // install has been clicked
 void managementWidget::installMultClicked()
 {
   int  i;
-  KPLVItem *it;
+  KpTreeListItem *it;
   packageInfo *inf;
   QPtrList<packageInfo> **lst = new QPtrList<packageInfo>*[kpinterfaceN];
 
   selList.clear();
-  findMarked(treeList->firstChild());
+  treeList->findMarked(treeList->firstChild(), selList);
+
   for (i = 0; i < kpinterfaceN; i++) {
     if (kpinterface[i]) {
       lst[i] = new QPtrList<packageInfo>;
@@ -454,7 +479,8 @@ void managementWidget::installMultClicked()
     if (kpinterface[i]) {
       if (lst[i]->count() > 0) {
 	kpinterface[i]->installation->setup(lst[i],kpinterface[i]->head);
-	if (kpinterface[i]->installation->exec()) {
+	if (kpinterface[i]->installation->exec() ||
+	    kpinterface[i]->installation->modified) {
 	  for (inf = lst[i]->first(); inf != 0; inf = lst[i]->next()) {
 	    updatePackage(inf,TRUE);
 	  }
@@ -464,6 +490,8 @@ void managementWidget::installMultClicked()
     }
   }
   delete [] lst;
+
+  checkMarked();
 }
 
 /////////////////////////////////////////////////////////////////////////////
@@ -474,36 +502,45 @@ void managementWidget::uninstallSingleClicked()
   int result;
   QPtrList<packageInfo> plist;
 
+  packageInfo *package = packageDisplay->package;
+
   if (package) {			// check that there is a package to uninstall
     pkgInterface *interface = package->interface;
     plist.append(package);
     interface->uninstallation->setup(&plist, interface->head);
     result = interface->uninstallation->exec();
 
-    if(result == QDialog::Accepted) { // execute it
-      // it was accepted, so the package has been uninstalled
+    if(result == QDialog::Accepted ||
+       interface->installation->modified) { 
       packageInfo *inf;
       for (inf = plist.first(); inf != 0; inf = plist.next()) {
 	updatePackage(inf,FALSE);
       }
 
-      emit changePackage(0); // change package to no package
-      package = 0;
+      if (treeList->currentItem()) {
+	KpTreeListItem *p = treeList->currentItem();
+	packageDisplay->changePackage(p->info);
+      } else {
+	packageDisplay->changePackage(0); // change package to no package
+      }
       setupInstButton();
     }
+    //    kdDebug() << "Result=" << result <<"\n";
   }
   kpackage->setPercent(100);
+
+  checkMarked();
 }
 
 void managementWidget::uninstallMultClicked()
 {
   int  i;
-  KPLVItem *it;
+  KpTreeListItem *it;
   packageInfo *inf;
   QPtrList<packageInfo> **lst = new QPtrList<packageInfo>*[kpinterfaceN];
 
   selList.clear();
-  findMarked(treeList->firstChild());
+  treeList->findMarked(treeList->firstChild(), selList);
   for (i = 0; i < kpinterfaceN; i++) {
     if (kpinterface[i]) {
       lst[i] = new QPtrList<packageInfo>;
@@ -524,7 +561,8 @@ void managementWidget::uninstallMultClicked()
     if (kpinterface[i]) {
       if (lst[i]->count() > 0) {
 	kpinterface[i]->uninstallation->setup(lst[i],kpinterface[i]->head);
-	if (kpinterface[i]->uninstallation->exec()) {
+	if (kpinterface[i]->uninstallation->exec()||
+	    kpinterface[i]->installation->modified ) {
 	  for (inf = lst[i]->first(); inf != 0; inf = lst[i]->next()) {
 	    updatePackage(inf,FALSE);
 	  }
@@ -534,204 +572,32 @@ void managementWidget::uninstallMultClicked()
     }
   }
   delete [] lst;
+
+  checkMarked();
 }
 
-///////////////////////////////////////////////////////////////////////////
-void managementWidget::sweep()
-{
-  KPLVItem  *item = treeList->firstChild();
-
-  if (!item)
-    return;
-
-  do {
-      sweepChild(item->firstChild());
-  } while ((item = item->nextSibling()));
-}
-
-int  managementWidget::sweepChild(KPLVItem *it)
-{
-  int ret, shown = 0;
-
-  do {
-    if (it->childCount() > 0) {
-      ret = sweepChild(it->firstChild());
-      if (!ret) {
-	it->hide();
-      } else {
-	it->show();
-      }
-      shown += ret;
-    } else {
-      //      printf("S=%s d=%d\n",(it->info->getProperty("name")).ascii(),
-      //      it->info->display(treeType));
-      if (!it->info->display(treeType)) {
-	it->hide();
-      } else {
-	it->show();
-	shown++;
-      }
-    }
-  } while ((it = it->nextSibling()));
-  return shown;
-}
-
-///////////////////////////////////////////////////////////////////////////
-KPLVItem *managementWidget::search(QString str, QString head,
-				KPLVItem  *start)
-{
-  KPLVItem  *item = treeList->firstChild();
-
-  searchCitem = start;
-  searchSkip = FALSE;
-  searchSubstr = FALSE;
-  searchStr = str;
-  searchResult = 0;
-
-  do {
-    if (item->text(0) == head) {
-      searchChild(item->firstChild());
-      if (searchResult != 0)
-	return searchResult;
-    }
-  } while ((item = item->nextSibling()));
-  return 0;
-}
-
-KPLVItem *managementWidget::search(QString str, bool subStr, bool wrap,
-			     bool start=FALSE)
-{
-  if (!treeList->firstChild())
-    return 0;
-
-  if (start)
-    searchCitem = 0;
-  else
-    searchCitem = treeList->currentItem();
-  searchSkip = !wrap;
-  searchSubstr = subStr;
-  searchStr = str;
-  searchResult = 0;
-
-  searchChild(treeList->firstChild());
-
-  return changePack(searchResult);
-}
-
-bool managementWidget::searchChild(KPLVItem *it)
-{
-  do {
-    if (!searchSkip) {
-      QString s = it->text(0);
-      //      kdDebug() << "s='" << s << "'='" <<  searchStr << "\n";
-      if ((it->childCount() == 0) && (it->info->display(treeType)) &&
-	  (searchSubstr ? s.contains(searchStr,FALSE) : s == searchStr)) {
-	searchResult = it;
-	return TRUE;
-      }
-    }
-
-    if (searchCitem == it) {
-      if (searchSkip) {
-	searchSkip = FALSE;
-      } else {
-	return TRUE;
-      }
-    }
-
-    if (it->childCount() > 0) {
-      if (searchChild(it->firstChild()))
-	return TRUE;
-    }
-  } while ((it = it->nextSibling()));
-  return FALSE;
-}
 
 ///////////////////////////////////////////////////////////////////////////
 
 void managementWidget::doChangePackage(packageInfo *p)
 {
-  emit changePackage(p);
+   packageDisplay->changePackage(p);
 }
 
 ///////////////////////////////////////////////////////////////////////////
-void managementWidget::stackRemove(KPLVItem *pack)
+
+KpTreeListItem *managementWidget::search(QString str, bool subStr, bool wrap,
+			     bool start)
 {
-  int n = stack.find(pack);
-  if (n >= 0) {
-    if (n == 0) {
-      kpkg->disablePrevious();
-    }
-    if (n >= int(stack.count() - 1)) {
-      kpkg->disableNext();
-    }
-    stack.remove(pack);
-  }
-}
-
-KPLVItem *managementWidget::changePack(KPLVItem *searchResult, bool push)
-{
-  if (searchResult) {
-    QListViewItem *i;
-
-    i = searchResult;
-    while ((i = i->parent())) {
-      i->setOpen(TRUE);
-    }
-    if (push) {
-      stack.append(searchResult);
-      kpkg->enablePrevious();
-    }
-
-    notPress = true;
-    treeList->setSelected(searchResult,TRUE);
-    treeList->setCurrentItem(searchResult);
-    treeList->ensureItemVisible(searchResult);
-    return searchResult;
-  } else {
-    return 0;
-  }
-}
-
-void managementWidget::next()
-{
-  int n = stack.at();
-  KPLVItem *s = stack.at(n + 1);
-  if (s) {
-    changePack(s, false);
-  }
-  if (n >= int(stack.count() - 2)) {
-    kpkg->disableNext();
-  }
-  if (n >= 0) {
-    kpkg->enablePrevious();
-  }
-}
-
-void managementWidget::previous()
-{
-  int n = stack.at();
-  KPLVItem *s = stack.at(n-1);
-
-  if (s) {
-    changePack(s, false);
-    kpkg->enableNext();
-  }
-  if (n <= 1) {
-    kpkg->disablePrevious();
-  }
-  if (n < int(stack.count() - 2)) {
-    kpkg->enableNext();
-  }
-
+  return treeList->search(str, subStr, wrap, start);
 }
 
 
 ///////////////////////////////////////////////////////////////////////////
-KPLVItem *managementWidget::updatePackage(packageInfo *pki, bool install)
+KpTreeListItem *managementWidget::updatePackage(packageInfo *pki, bool install)
 {
   QString version;
-  KPLVItem *q;
+  KpTreeListItem *q;
 
   if (allPackages) {
     QString name(pki->getProperty("name"));
@@ -773,16 +639,17 @@ KPLVItem *managementWidget::updatePackage(packageInfo *pki, bool install)
 	if (!q) {
 	  printf("NOTP=%s \n",pnew->getProperty("name").ascii());
 	} else {
-	  sweep();
+	  treeList->sweep(true);
+	  searchLine->updateSearch();
 	  return q;
 	}
       }
     } else { // uninstalling
       if (!pnew) {
 	dirInstPackages->remove(pkgId);
-	KPLVItem  *qt = pki->getItem();
+	KpTreeListItem  *qt = pki->getItem();
 	if (qt) {
-	  stackRemove(qt);
+	  treeList->stackRemove(qt);
 	  treeList->setSelected(qt,false);
 	  if (treeList->markPkg == qt)
 	    treeList->markPkg = 0;
@@ -797,7 +664,8 @@ KPLVItem *managementWidget::updatePackage(packageInfo *pki, bool install)
 	  if (!q) {
 	    printf("NOTP=%s \n",pb->getProperty("name").ascii());
 	  } else {
-	    sweep();
+	    treeList->sweep(true);
+	    searchLine->updateSearch();
 	    return q;
 	  }
 	}
@@ -807,124 +675,20 @@ KPLVItem *managementWidget::updatePackage(packageInfo *pki, bool install)
       }
     }
   }
-  sweep();
+  treeList->sweep(true);
+  searchLine->updateSearch();
+
   return 0;
 }
 
 ///////////////////////////////////////////////////////////////////////////
-void managementWidget::clearMarked(KPLVItem *item)
+void managementWidget::checkMarked()
 {
-  while (item) {
-    if (item->childCount() > 0) {
-      clearMarked(item->firstChild());
-    }
-    item->setMark(false);
-    item = item->nextSibling();
-  }
-}
+int  cntInstall = 0;
+int  cntUnInstall = 0;
 
-void managementWidget::findMarked(KPLVItem *item)
-{
-  while (item) {
-    if (item->childCount() > 0) {
-      findMarked(item->firstChild());
-    }
-    if (item->marked) {
-      selList.insert(0,item);
-    }
-    item = item->nextSibling();
-  }
-}
-
-///////////////////////////////////////////////////////////////////////////
-void managementWidget::expandTree(KPQListView *list)
-{
- KPLVItem *item = list->firstChild();
-
-  while (item) {
-    if (item->childCount() > 0) {
-      item->setOpen(TRUE);
-      expandTree(item);
-    }
-  item = item->nextSibling();
-  }
-}
-
-
-void managementWidget::expandTree(KPLVItem *pitem)
-{
-  KPLVItem *item = pitem->firstChild();
-
-  while (item) {
-    if (item->childCount() > 0) {
-      item->setOpen(TRUE);
-      expandTree(item);
-    }
-    item = item->nextSibling();
-  }
-}
-
-void managementWidget::collapseTree(KPQListView *list)
-{
-  KPLVItem *item = list->firstChild();
-
-  while (item) {
-    if (item->childCount() > 0) {
-      collapseTree(item);
-    }
-  item = item->nextSibling();
-  }
-}
-
-void managementWidget::collapseTree(KPLVItem *pitem)
-{
-  int n = 0;
-  KPLVItem *item = pitem->firstChild();
-
-  while (item) {
-    if (item->childCount() > 0) {
-      n++;
-      collapseTree(item);
-    }
-    item = item->nextSibling();
-  };
-  if (n)
-    pitem->setOpen(TRUE);
-  else
-    pitem->setOpen(FALSE);
-}
-
-///////////////////////////////////////////////////////////////////////////
-void managementWidget::writeTreePos()
-{
-  int i;
-
-  KConfig *config = kapp->config();
-
-  config->setGroup("Treelist");
-
-  QString colpos;
-  for (i = 0; i < 5; i++) {
-    colpos.setNum(i);
-    config->writeEntry(colpos,treeList->columnWidth(i));
-  }
-}
-
-void managementWidget::readTreePos()
-{
-  int i, n;
-  int num[] = {185,37,54,95,95};
-
-  KConfig *config = kapp->config();
-
-  config->setGroup("Treelist");
-
-  QString colpos;
-  for (i = 0; i < 5; i++) {
-    colpos.setNum(i);
-    n = config->readNumEntry(colpos,num[i]);
-    treeList->setColumnWidth(i,n);
-  }
+  treeList->countMarked(treeList->firstChild(), cntInstall, cntUnInstall);
+  setupMultButton(cntInstall, cntUnInstall);
 }
 
 
