@@ -1,5 +1,4 @@
-/* options.h
-**
+/*
 ** Copyright (C) 1999,2000 Toivo Pedaste <toivo@ucs.uwa.edu.au>
 **
 */
@@ -136,7 +135,7 @@ private slots:
 class Opts
 {
 public:
-  void readSettings(QString initHost = "");
+  void readSettings(const QString &initHost = "");
   void writeSettings();
 
   void readLaterSettings();
