@@ -1,5 +1,4 @@
-/* packageInfo.cpp
-**
+/*
 ** Copyright (C) 1999,2000 Toivo Pedaste <toivo@ucs.uwa.edu.au>
 **
 // Author: Damyan Pepper
@@ -71,7 +70,7 @@ packageInfo::packageInfo(QDict<QString> *_info, pkgInterface *type)
 }
 
 // Another constructor, for a packge with a url
-packageInfo::packageInfo(QDict<QString> *_info, QString _url)
+packageInfo::packageInfo(QDict<QString> *_info, const QString &_url)
 {
   info = _info;
   url = _url;
@@ -114,7 +113,7 @@ void packageInfo::fixup()
 {
   if (!info->find("name")) {
     QString *q = new QString();
-    q->setNum((int)this);
+    q->setNum((long)this);
     info->insert("name", q);
   }
 
@@ -129,7 +128,7 @@ void packageInfo::fixup()
 }
 
 // Set the file name
-void packageInfo::setFilename(QString f)
+void packageInfo::setFilename(const QString &f)
 {
   url = f;
 }
@@ -199,10 +198,12 @@ QString packageInfo::getFilename()
   }
 }
 
-int packageInfo::getDigElement(QString s, int *pos)
+int packageInfo::getDigElement(const QString &str, int *pos)
   // Extract the next element from the string
   // All digits
 {
+	QString s = str;
+
   if (*pos < 0)
     return -1;
 
@@ -230,10 +231,12 @@ int packageInfo::getDigElement(QString s, int *pos)
   return val;
 }
 
-QString packageInfo::getNdigElement(QString s, int *pos)
+QString packageInfo::getNdigElement(const QString &string, int *pos)
   // Extract the next element from the string
   // All  all non-digits
 {
+  QString s(string);
+
   if (*pos < 0)
     return QString::null;
 
@@ -265,7 +268,7 @@ QString packageInfo::getNdigElement(QString s, int *pos)
 }
 
 
-int packageInfo::pnewer(QString s, QString sp)
+int packageInfo::pnewer(const QString &s, const QString &sp)
 {
   int ns = 0, nsp = 0, vs, vsp;
 
@@ -396,9 +399,9 @@ bool packageInfo::display(int treeType)
 //////////////////////////////////////////////////////////////////////
 // Place the package in a QListView
 
-KPLVItem *packageInfo::place(KPQListView *tree, bool insertI)
+KpTreeListItem *packageInfo::place(KpTreeList *tree, bool insertI)
 {
-  KPLVItem *search = tree->firstChild(), *parent=NULL, *child=NULL;
+  KpTreeListItem *search = tree->firstChild(), *parent=NULL, *child=NULL;
   QString qtmp, tmp;
   bool doit = FALSE;
 
@@ -414,7 +417,7 @@ KPLVItem *packageInfo::place(KPQListView *tree, bool insertI)
 
     QStringList list = QStringList::split("/",qtmp);
     for ( QStringList::Iterator it = list.begin(); it != list.end(); ++it ) {
-      KPLVItem *group;
+      KpTreeListItem *group;
 
       if( search && (group=findGroup(*it, search)) ) {
 	parent = group;
@@ -422,9 +425,9 @@ KPLVItem *packageInfo::place(KPQListView *tree, bool insertI)
 	search = group->firstChild();
       } else {
 	if (parent) {
-	  group = new KPLVItem(parent, 0, interface->folder, *it);
+	  group = new KpTreeListItem(parent, 0, interface->folder, *it);
 	} else {
-	  group = new KPLVItem(tree, 0, interface->folder, *it);
+	  group = new KpTreeListItem(tree, 0, interface->folder, *it);
 	}
 	parent = group;
 	parent->setOpen(TRUE);
@@ -465,6 +468,11 @@ KPLVItem *packageInfo::place(KPQListView *tree, bool insertI)
     if (info->find("old-version")) {
       over = *info->find("old-version");
     }
+    QString summary = "";
+    if (info->find("summary")) {
+      summary = *info->find("summary");
+    }
+       
 
     QPixmap pic;
     if (packageState == BAD_INSTALL) {
@@ -480,9 +488,9 @@ KPLVItem *packageInfo::place(KPQListView *tree, bool insertI)
     }
 
     if (child) {
-      item =  new KPLVItem(child, this, pic, tmp, "", sz, ver, over);
+      item =  new KpTreeListItem(child, this, pic, tmp, "", summary, sz, ver, over);
     } else {
-      item = new KPLVItem(parent, this, pic, tmp, "", sz, ver, over);
+      item = new KpTreeListItem(parent, this, pic, tmp, "", summary, sz, ver, over);
     }
 
     if (insertI) {
@@ -500,7 +508,7 @@ KPLVItem *packageInfo::place(KPQListView *tree, bool insertI)
 //////////////////////////////////////////////////////////////////////
 
 // Get the QListViewItem
-KPLVItem *packageInfo::getItem()
+KpTreeListItem *packageInfo::getItem()
 {
   return item;
 }
@@ -528,7 +536,7 @@ bool packageInfo::smerge( const QString &exp) {
 }
 
 //////////////////////////////////////////////////////////////////////////////
-void packageInfo::pkgFileIns(QString fileName)
+void packageInfo::pkgFileIns(const QString &fileName)
 {
   info->insert("filename", new QString(fileName));
   info->insert("base", new QString(""));
