@@ -1,5 +1,4 @@
-/* packageInfo.h
-**
+/*
 ** Copyright (C) 1999,2000 Toivo Pedaste <toivo@ucs.uwa.edu.au>
 **
 // Author: Damyan Pepper
@@ -53,8 +52,8 @@
 #include <qlistview.h>
 
 class pkgInterface;
-class KPLVItem;
-class KPQListView;
+class KpTreeListItem;
+class KpTreeList;
 
 //////////////////////////////////////////////////////////////////////////////
 //////////////////////////////////////////////////////////////////////////////
@@ -65,7 +64,7 @@ public:
   // Constructor: create a packageInfo object using the property
   // dictionary from _info
 
-  packageInfo(QDict<QString> *_info, QString _filename);
+  packageInfo(QDict<QString> *_info, const QString &_filename);
   // Constructor: same as above, but also sets filename to _filename.
   // This is used in the case that the package info was obtained from
   // an uninstalled package.
@@ -86,18 +85,18 @@ public:
   void fixup();
   // Initialize fields if missing
 
-  KPLVItem *place(KPQListView *tree, bool InsertI=FALSE);
+  KpTreeListItem *place(KpTreeList *tree, bool InsertI=FALSE);
   // places the object in the treelist `tree' and initialises
   // `item'.  If necessary, new groups will be added to `tree'.
 
-  KPLVItem  *getItem();
+  KpTreeListItem  *getItem();
   // returns the treelist item object for this package or
   // NULL if the object hasn't been placed
 
   QDict<QString> *getDict();
   // returns the property dictionary for the package
 
-  void setFilename(QString f);
+  void setFilename(const QString &f);
 
   QString getUrl();
   // return URL of package file
@@ -119,7 +118,7 @@ public:
   int newer(packageInfo *p);
   // if package p is newer
 
-  void pkgFileIns(QString fileName);
+  void pkgFileIns(const QString &fileName);
   // Insert a package from a file into package tree
 
   bool pkgInsert(QPtrList<packageInfo> *pki, const QString &exp, bool installed,
@@ -129,7 +128,7 @@ public:
   QDict<QString> *info;
   // This stores the property dictionary of the package
 
-  KPLVItem *item;
+  KpTreeListItem *item;
   // This stores the tree list item for this package (or NULL if
   // the package hasn't been placed in a tree list)
 
@@ -149,11 +148,11 @@ public:
   bool updated;
 
 private:
-  int getDigElement(QString s, int *pos);
-  QString getNdigElement(QString s, int *pos);
+  int getDigElement(const QString &s, int *pos);
+  QString getNdigElement(const QString &s, int *pos);
   // break up version string
 
-  int pnewer(QString s, QString sp);
+  int pnewer(const QString &s, const QString &sp);
   // compare parts of a version string
   
   QString url;
