@@ -1,5 +1,4 @@
-/* packageProperties.cpp
-**
+/*
 ** Copyright (C) 1999,2000 Toivo Pedaste <toivo@ucs.uwa.edu.au>
 **
 */
@@ -30,6 +29,8 @@
 #include <stdio.h>
 #include <kdebug.h>
 
+#include <kapplication.h> 
+
 #include "kpackage.h"
 #include "packageProperties.h"
 #include "pkgInterface.h"
@@ -54,7 +55,7 @@ packagePropertiesWidget::~packagePropertiesWidget()
 {
 }
 
-void packagePropertiesWidget::iList(QString txt, QString itxt)
+void packagePropertiesWidget::iList(const QString &txt, const QString &itxt)
 {
   trl.insert(txt, new QString(itxt));
   pList.append(txt);
@@ -73,6 +74,7 @@ void packagePropertiesWidget::initTranslate()
   iList("size", i18n("size"));
   iList("file-size", i18n("file-size"));
   iList("description", i18n("description"));
+  iList("url", i18n("url")); 
   iList("architecture", i18n("architecture"));
 
   iList("unsatisfied dependencies", i18n("unsatisfied dependencies"));
@@ -166,6 +168,11 @@ void packagePropertiesWidget::changePackage(packageInfo *p)
 		 *s == "suggests"  || *s == "recommends" ||
 		 *s == "pre-depends" || *s == "unsatisfied dependencies") {
 	depends(f);
+      } else if (*s == "url") {
+        if (f.right(1) == " ") f.remove(f.length()-1, 1);
+        if  (f.startsWith("http:") || f.startsWith("ftp:"))  /*if (!(f == "(none)")) */
+        stmp += "<a href=\"" + f +"\">" + f + "</a>";
+        else stmp += i18n("none");
       } else {
 	stmp += f;
       }
@@ -241,21 +248,28 @@ void  packagePropertiesWidget::delement(const QString &f) {
 void  packagePropertiesWidget::setSource(const QString &name) {
   QString s = name;
 
+  if (s.startsWith("http:") || s.startsWith("ftp:"))
+  {
+    KApplication::kApplication()->invokeBrowser( s );
+    return;
+  }
+  
   if (s.startsWith("file:")) {
     s = s.mid(5);
   }
   else if (s.at(1) == '/') {
     s = s.mid(1);
   }
+  
   QString ind = s + package->interface->typeID;
   packageInfo *p = kpackage->management->dirInstPackages->find(ind);
   if (p) {
-     kpackage->management->changePack(p->getItem(), package->getItem() != 0);
+     kpackage->management->treeList->changePack(p->getItem(), package->getItem() != 0);
   } else {
     kdDebug() << "nfound=" << ind << endl;
     p = kpackage->management->dirUninstPackages->find(ind);
     if (p) {
-       kpackage->management->changePack(p->getItem(), package->getItem() != 0);
+       kpackage->management->treeList->changePack(p->getItem(), package->getItem() != 0);
     } else {
       kdDebug() << "Nfound=" << ind << endl;
     }
