@@ -1,5 +1,4 @@
-/* packageProperties.h
-**
+/*
 ** Copyright (C) 1999,2000 Toivo Pedaste <toivo@ucs.uwa.edu.au>
 **
 // Author: Damyan Pepper
@@ -76,7 +75,7 @@ private:
   packageInfo *package;
 
   void initTranslate();
-  void iList(QString txt, QString itxt);
+  void iList(const QString &txt, const QString &itxt);
 
   QDict<QString> trl ;
   // allow for translation of labels
