@@ -1,5 +1,4 @@
-/* slackInterface.cpp
-**
+/*
 ** Copyright (C) 1999,2000 Toivo Pedaste <toivo@ucs.uwa.edu.au>
 **
 */
@@ -176,7 +175,7 @@ void SLACK::listPackages(QPtrList<packageInfo> *pki)
     for (cp = packageLoc->first(); cp != 0; cp = packageLoc->next()) {
       if (cp->cacheFile == "SLACK_0_0") {
 	// already done
-      } else if (cp->base != "") {
+      } else if ( !cp->base.isEmpty() ) {
 	s = getPackList(cp);
 	if (!s.isEmpty()) {
 	  listPackList(pki, s, cp, UNINSTALLED);
@@ -274,7 +273,7 @@ void SLACK::listPackList(QPtrList<packageInfo> *pki, QString s,  cacheObj *cp, i
       }
       if (strcmp(linebuf,"\n")) {
 	vb += linebuf;
-      } else if (vb != "") {
+      } else if ( !vb.isEmpty() ) {
 	p = collectInfo(vb.ascii(), insState);
 	if (p) {
 	  if (!p->pkgInsert(pki, typeID, insState == INITIAL, insState == INITIAL)) {
@@ -585,7 +584,7 @@ QString SLACK::install(int installFlags, QPtrList<packageInfo> *plist, bool &tes
   QString packs = "";
   for (pk = plist->first(); pk != 0; pk = plist->next()) {
     QString fname = pk->fetchFilename();
-    if (fname != "") {
+    if ( !fname.isEmpty() ) {
       packs += fname + " ";
       i++;
     }
@@ -607,7 +606,7 @@ QString SLACK::doInstall(int installFlags, QString packs, bool &)
 
 //////////////////////////////////////////////////////////////////////////////
 //////////////////////////////////////////////////////////////////////////////
-QStringList SLACK::FindFile(const QString &name)
+QStringList SLACK::FindFile(const QString &name, bool)
 {
   FILE *file;
   char linebuf[1024];
