@@ -1,5 +1,4 @@
-/* utils.cpp
-**
+/*
 ** Copyright (C) 1999,2000 Toivo Pedaste <toivo@ucs.uwa.edu.au>
 **
 */
@@ -46,7 +45,7 @@ void KpMsg(QString lab, QString msg, bool stop)
     KMessageBox::information(kpkg, msg, lab);
 }
 
-KPLVItem *findGroup(QString name, KPLVItem *search)
+KpTreeListItem *findGroup(const QString &name, KpTreeListItem *search)
 {
   if(!search)
     return NULL;
