@@ -1,5 +1,4 @@
-/* utils.h
-**
+/*
 ** Copyright (C) 1999,2000 Toivo Pedaste <toivo@ucs.uwa.edu.au>
 **
 */
@@ -25,13 +24,16 @@
 ** Bug reports and questions can be sent to kde-devel@kde.org
 */
 
+#ifndef _UTILS_H_
+#define _UTILS_H_
 
 #include "../config.h"
 #include <string.h>
 #include <klistview.h>
 
-class KPLVItem;
+class KpTreeListItem;
 
-KPLVItem *findGroup(QString ame, KPLVItem *search);
+KpTreeListItem *findGroup(const QString &name, KpTreeListItem *search);
 
+#endif
 
