@@ -18,8 +18,8 @@
  *  Boston, MA 02111-1307, USA.
  **/
 
-#ifndef _KUSER_H_
-#define _KUSER_H_
+#ifndef _KU_USER_H_
+#define _KU_USER_H_
 
 #include <sys/types.h>
 
@@ -33,11 +33,17 @@ class KUsers;
 
 class KUser {
 public:
+  enum Cap {
+    Cap_POSIX = 1,
+    Cap_Samba = 2
+  };
   KUser();
   KUser(const KUser *user);
   ~KUser();
 
   void copy(const KUser *user);
+  void setCaps( int data );
+  int getCaps();
 
   const QString &getName() const;
   const QString &getSurname() const;
@@ -60,7 +66,7 @@ public:
   const QString &getOffice2() const;
   const QString &getAddress() const;
 
-//shadow  
+//shadow
   const QString &getSPwd() const;
   time_t getExpire() const;
   time_t getLastChange() const;
@@ -70,16 +76,18 @@ public:
   int getInactive() const;
   int getFlag() const;
 
-//samba  
+//samba
   const QString &getLMPwd() const; //  sam_lmpwd,
   const QString &getNTPwd() const; //sam_ntpwd,
   const QString &getLoginScript() const; //sam_loginscript,
   const QString &getProfilePath() const; //  sam_profile,
   const QString &getHomeDrive() const; //sam_homedrive,
   const QString &getHomePath() const; //sam_homepath;
+  const QString &getWorkstations() const; //sam_workstations
+  const QString &getDomain() const; //sam_domain
   const SID &getSID() const; //sid,
   const SID &getPGSID() const; //pgroup_sid;
-
+  
   void setName(const QString &data);
   void setSurname(const QString &data);
   void setEmail(const QString &data);
@@ -117,6 +125,8 @@ public:
   void setProfilePath( const QString &data); //  sam_profile,
   void setHomeDrive( const QString &data ); //sam_homedrive,
   void setHomePath( const QString &data ); //sam_homepath;
+  void setWorkstations( const QString &data ); //sam_workstations
+  void setDomain( const QString &data ); //sam_domain
   void setSID( const SID &data ); //sid,
   void setPGSID( const SID &data ); //pgroup_sid;
   
@@ -134,7 +144,7 @@ public:
 
 protected:
   friend class KUsers;
-  
+
   int createHome();
   int tryCreate(const QString &dir);
   int createMailBox();
@@ -147,6 +157,7 @@ protected:
 
   void copyDir(const QString &srcPath, const QString &dstPath);
 
+  int caps;
   QString
     p_name,                        // parsed pw information
     p_surname,
@@ -177,7 +188,9 @@ protected:
     sam_loginscript,
     sam_profile,
     sam_homedrive,
-    sam_homepath;
+    sam_homepath,
+    sam_workstations,
+    sam_domain;
   SID 
     sid,
     pgroup_sid;
@@ -204,7 +217,8 @@ public:
     Cap_Shadow = 4,
     Cap_InetOrg = 8,
     Cap_Samba = 16,
-    Cap_BSD = 32
+    Cap_Disable_POSIX = 32,
+    Cap_BSD = 64
   };
   typedef QPtrListIterator<KUser> DelIt;
   typedef QPtrListIterator<KUser> AddIt;
@@ -237,7 +251,7 @@ public:
   void cancelMods();
   
   enum {
-	NO_FREE = (uid_t) -1
+    NO_FREE = (uid_t) -1
   };
 
   /**
@@ -278,8 +292,10 @@ protected:
   
   bool doCreate( KUser *user );
   bool doDelete( KUser *user );
+  void parseGecos( const char *gecos, QString &name,
+    QString &field1, QString &field2, QString &field3 );
   void fillGecos( KUser *user, const char *gecos );
   
 };
 
-#endif // _KUSER_H_
+#endif // _KU_USER_H_
