@@ -21,7 +21,7 @@
 #include <stdio.h>
 #include <stdlib.h>
 
-#include <qdatetm.h>
+#include <qdatetime.h>
 #include <qwhatsthis.h>
 #include <qlayout.h>
 #include <qgroupbox.h>
@@ -99,7 +99,7 @@ KIntSpinBox *propdlg::addDaysGroup(QWidget *parent, QGridLayout *layout, int row
 void propdlg::initDlg()
 {
   ro = kug->getUsers().getCaps() & KUsers::Cap_ReadOnly;
-  
+
   QString whatstr;
 
   // Tab 1: User Info
@@ -110,12 +110,11 @@ void propdlg::initDlg()
 
     frontpage = frame;
     frontlayout = layout;
-    
+
     lbuser = new QLabel(frame);
 //    whatstr = i18n("WHAT IS THIS: User login");
     addRow(frame, layout, row++, lbuser, i18n("User login:"), whatstr, false, false);
-    
-    
+
     leid = new KLineEdit(frame);
 //    whatstr = i18n("WHAT IS THIS: User Id");
     leid->setValidator(new QIntValidator(frame));
@@ -206,6 +205,14 @@ void propdlg::initDlg()
     connect(cbdisabled, SIGNAL(stateChanged(int)), this, SLOT(changed()));
     addRow(frame, layout, row++, cbdisabled, i18n("Account &disabled"), whatstr);
 
+    if ( kug->getUsers().getCaps() & KUsers::Cap_Disable_POSIX ) {
+      cbposix = new QCheckBox(frame);
+      connect(cbposix, SIGNAL(stateChanged(int)), this, SLOT(changed()));
+      connect(cbposix, SIGNAL(stateChanged(int)), this, SLOT(cbposixChanged()));
+      addRow(frame, layout, row++, cbposix, i18n("Disable &POSIX account information"), whatstr);
+    } else {
+      cbposix = 0;
+    }
     frontrow = row;
   }
 
@@ -226,14 +233,21 @@ void propdlg::initDlg()
     row++;
 
     if ( kug->getUsers().getCaps() & KUsers::Cap_Shadow ) {
+      layout->addWidget( new QLabel( "POSIX parameters:", frame ), row++, 0 );
       lesmin = addDaysGroup(frame, layout, row++, i18n("Time before password may &not be changed after last password change:"), false);
       lesmax = addDaysGroup(frame, layout, row++, i18n("Time when password &expires after last password change:") );
       leswarn = addDaysGroup(frame, layout, row++, i18n("Time before password expires to &issue an expire warning:"));
       lesinact = addDaysGroup(frame, layout, row++, i18n("Time when account will be &disabled after expiration of password:"));
+      layout->addMultiCellWidget(new KSeparator(KSeparator::HLine, frame), row, row, 0, 3);
+      row++;
     }
-    layout->addMultiCellWidget(new KSeparator(KSeparator::HLine, frame), row, row, 0, 3);
-    row++;
-
+    /*
+    if ( kug->getUsers().getCaps() & KUsers::Cap_Samba ) {
+      layout->addWidget( new QLabel( "SAMBA parameters:", frame ), row++, 0 );
+      layout->addMultiCellWidget(new KSeparator(KSeparator::HLine, frame), row, row, 0, 3);
+      row++;
+    }
+    */
     QLabel *label = new QLabel( i18n("&Account will expire on:"), frame );
     layout->addWidget( label, row, 0 );
     lesexpire = new KDateTimeWidget( frame );
@@ -280,10 +294,25 @@ void propdlg::initDlg()
     addRow(frame, layout, row++, lehomepath, i18n("Home path:"), whatstr);
     connect(lehomepath, SIGNAL(textChanged(const QString &)), this, SLOT(changed()));
 
+    leworkstations = new KLineEdit(frame);
+//  whatstr = i18n("WHAT IS THIS: Login script");
+    addRow(frame, layout, row++, leworkstations, i18n("User workstations:"), whatstr);
+    connect(leworkstations, SIGNAL(textChanged(const QString &)), this, SLOT(changed()));
+
+    ledomain = new KLineEdit(frame);
+//  whatstr = i18n("WHAT IS THIS: Login script");
+    addRow(frame, layout, row++, ledomain, i18n("Domain name:"), whatstr);
+    connect(ledomain, SIGNAL(textChanged(const QString &)), this, SLOT(changed()));
+
     ledomsid = new KLineEdit(frame);
 //  whatstr = i18n("WHAT IS THIS: Login script");
     addRow(frame, layout, row++, ledomsid, i18n("Domain SID:"), whatstr);
     connect(ledomsid, SIGNAL(textChanged(const QString &)), this, SLOT(changed()));
+
+    cbsamba = new QCheckBox(frame);
+    connect(cbsamba, SIGNAL(stateChanged(int)), this, SLOT(changed()));
+    connect(cbsamba, SIGNAL(stateChanged(int)), this, SLOT(cbsambaChanged()));
+    addRow(frame, layout, row++, cbsamba, i18n("Disable &Samba account information"), whatstr);
   }
 
   // Tab 4: Groups
@@ -342,6 +371,33 @@ propdlg::~propdlg()
 {
 }
 
+void propdlg::cbposixChanged()
+{
+  bool posix = !( cbposix->state() == QButton::On );
+  leid->setEnabled( posix  & ( mUsers.getFirst() == mUsers.getLast() ) );
+  leshell->setEnabled( posix );
+  lehome->setEnabled( posix );
+  if ( kug->getUsers().getCaps() & KUsers::Cap_Shadow ) {
+    lesmin->setEnabled( posix );
+    lesmax->setEnabled( posix );
+    leswarn->setEnabled( posix );
+    lesinact->setEnabled( posix );
+  }
+}
+
+void propdlg::cbsambaChanged()
+{
+  bool samba = !( cbsamba->state() == QButton::On );
+  lerid->setEnabled( samba & ( mUsers.getFirst() == mUsers.getLast() ) );
+  leliscript->setEnabled( samba );
+  leprofile->setEnabled( samba );
+  lehomedrive->setEnabled( samba );
+  lehomepath->setEnabled( samba );
+  leworkstations->setEnabled( samba );
+  ledomain->setEnabled( samba );
+  ledomsid->setEnabled( samba );
+}
+
 void propdlg::setLE( KLineEdit *le, const QString &val, bool first )
 {
   if ( first ) {
@@ -404,7 +460,7 @@ void propdlg::selectuser()
   if ( kug->getUsers().getCaps() & KUsers::Cap_Shadow ||
        kug->getUsers().getCaps() & KUsers::Cap_Samba ||
        kug->getUsers().getCaps() & KUsers::Cap_BSD ) {
-    
+
     leslstchg->setText( KGlobal::locale()->formatDateTime( datetime, false ) );
   }
 
@@ -459,6 +515,9 @@ void propdlg::selectuser()
     }
 
     setCB( cbdisabled, user->getDisabled(), first );
+    if ( kug->getUsers().getCaps() & KUsers::Cap_Disable_POSIX ) {
+      setCB( cbposix, !(user->getCaps() & KUser::Cap_POSIX), first );
+    }
 
     if ( kug->getUsers().getCaps() & KUsers::Cap_Samba ) {
       setLE( leliscript, user->getLoginScript(), first );
@@ -470,7 +529,10 @@ void propdlg::selectuser()
       home = user->getHomePath();
       if ( !one ) home.replace( user->getName(), "%U" );
       setLE( lehomepath, home, first );
+      setLE( leworkstations, user->getWorkstations(), first );
+      setLE( ledomain, user->getDomain(), first );
       setLE( ledomsid, user->getSID().getDOM(), first );
+      setCB( cbsamba, !(user->getCaps() & KUser::Cap_Samba), first );
     }
 
     if ( kug->getUsers().getCaps() & KUsers::Cap_Shadow ||
@@ -643,12 +705,21 @@ void propdlg::mergeUser( KUser *user, KUser *newuser )
   QDateTime epoch ;
   epoch.setTime_t(0);
   bool one = ( mUsers.getFirst() == mUsers.getLast() );
+  bool posix, samba = false;
 
   newuser->copy( user );
 
+  if ( kug->getUsers().getCaps() & KUsers::Cap_Disable_POSIX && cbposix->state() != QButton::NoChange ) {
+    if ( cbposix->isChecked() )
+      newuser->setCaps( newuser->getCaps() & ~KUser::Cap_POSIX );
+    else
+      newuser->setCaps( newuser->getCaps() | KUser::Cap_POSIX );
+  }
+  posix = newuser->getCaps() & KUser::Cap_POSIX;
+  kdDebug() << "posix: " << posix << endl;
   if ( one ) {
 //    newuser->setName( leuser->text() );
-    newuser->setUID( leid->text().toInt() );
+    newuser->setUID( posix ? leid->text().toInt() : 0 );
   }
   if ( !newpass.isNull() ) {
     kug->getUsers().createPassword( newuser, newpass );
@@ -656,14 +727,33 @@ void propdlg::mergeUser( KUser *user, KUser *newuser )
   }
   newuser->setFullName( mergeLE( lefname, user->getFullName(), one ) );
   if ( kug->getUsers().getCaps() & KUsers::Cap_Samba ) {
+    if ( cbsamba->state() != QButton::NoChange ) {
+      if ( cbsamba->isChecked() )
+        newuser->setCaps( newuser->getCaps() & ~KUser::Cap_Samba );
+      else
+        newuser->setCaps( newuser->getCaps() | KUser::Cap_Samba );
+    }
+    samba = newuser->getCaps() & KUser::Cap_Samba;
+    kdDebug() << "user : " << newuser->getName() << " caps: " << newuser->getCaps() << " samba: " << samba << endl;
+
     SID sid;
-    sid.setRID( one ? lerid->text().toUInt() : user->getSID().getRID() );
-    sid.setDOM( mergeLE( ledomsid, user->getSID().getDOM(), one ) );
+    if ( samba ) {
+      sid.setRID( one ? lerid->text().toUInt() : user->getSID().getRID() );
+      sid.setDOM( mergeLE( ledomsid, user->getSID().getDOM(), one ) );
+    }
     newuser->setSID( sid );
-    newuser->setLoginScript( mergeLE( leliscript, user->getLoginScript(), one ) );
-    newuser->setProfilePath( mergeLE( leprofile, user->getProfilePath(), one ).replace( "%U", newuser->getName() ) );
-    newuser->setHomeDrive( mergeLE( lehomedrive, user->getHomeDrive(), one ) );
-    newuser->setHomePath( mergeLE( lehomepath, user->getHomePath(), one ).replace( "%U", newuser->getName() ) );
+    newuser->setLoginScript( samba ? 
+      mergeLE( leliscript, user->getLoginScript(), one ) : QString::null  );
+    newuser->setProfilePath( samba ? 
+      mergeLE( leprofile, user->getProfilePath(), one ).replace( "%U", newuser->getName() ) : QString::null );
+    newuser->setHomeDrive( samba ? 
+      mergeLE( lehomedrive, user->getHomeDrive(), one ) : QString::null );
+    newuser->setHomePath( samba ? 
+      mergeLE( lehomepath, user->getHomePath(), one ).replace( "%U", newuser->getName() ) : QString::null );
+    newuser->setWorkstations( samba ? 
+      mergeLE( leworkstations, user->getWorkstations(), one ) : QString::null );
+    newuser->setDomain( samba ? 
+      mergeLE( ledomain, user->getDomain(), one ) : QString::null );
   }
 
   if ( kug->getUsers().getCaps() & KUsers::Cap_BSD ) {
@@ -677,18 +767,23 @@ void propdlg::mergeUser( KUser *user, KUser *newuser )
     newuser->setAddress( mergeLE( leaddress, user->getAddress(), one ) );
   }
 
-  newuser->setHomeDir( mergeLE( lehome, user->getHomeDir(), one ).replace( "%U", newuser->getName() ) );
-  if ( leshell->currentItem() == 0 && ismoreshells ) {
-    newuser->setShell( user->getShell() );
-  } else if  (
-    ( leshell->currentItem() == 0 && !ismoreshells ) ||
-    ( leshell->currentItem() == 1 && ismoreshells ) ) {
+  newuser->setHomeDir( posix ? 
+    mergeLE( lehome, user->getHomeDir(), one ).replace( "%U", newuser->getName() ) : 
+    QString::null );
+  if ( posix ) {
+    if ( leshell->currentItem() == 0 && ismoreshells ) {
+      newuser->setShell( user->getShell() );
+    } else if  (
+      ( leshell->currentItem() == 0 && !ismoreshells ) ||
+      ( leshell->currentItem() == 1 && ismoreshells ) ) {
 
-    newuser->setShell( QString::null );
-  } else {
+      newuser->setShell( QString::null );
+    } else {
   // TODO: Check shell.
-    newuser->setShell( leshell->currentText() );
-  }
+      newuser->setShell( leshell->currentText() );
+    }
+  } else
+    newuser->setShell( QString::null );
 
   newuser->setDisabled( (cbdisabled->state() == QButton::NoChange) ? user->getDisabled() : cbdisabled->isChecked() );
 
@@ -698,15 +793,15 @@ void propdlg::mergeUser( KUser *user, KUser *newuser )
   }
 
   if ( kug->getUsers().getCaps() & KUsers::Cap_Shadow ) {
-    newuser->setMin( mergeSB( lesmin, user->getMin(), one ) );
-    newuser->setMax( mergeSB( lesmax, user->getMax(), one ) );
-    newuser->setWarn( mergeSB( leswarn, user->getWarn(), one ) );
-    newuser->setInactive( mergeSB( lesinact, user->getInactive(), one ) );
+    newuser->setMin( posix ? mergeSB( lesmin, user->getMin(), one ) : 0 );
+    newuser->setMax( posix ? mergeSB( lesmax, user->getMax(), one ) : 0 );
+    newuser->setWarn( posix ? mergeSB( leswarn, user->getWarn(), one ) : 0 );
+    newuser->setInactive( posix ? mergeSB( lesinact, user->getInactive(), one ) : 0 );
   }
 
-  if ( kug->getUsers().getCaps() & KUsers::Cap_Shadow ||
-       kug->getUsers().getCaps() & KUsers::Cap_Samba ||
-       kug->getUsers().getCaps() & KUsers::Cap_BSD ) {
+  if ( ( (kug->getUsers().getCaps() & KUsers::Cap_Shadow) && posix ) ||
+       ( (kug->getUsers().getCaps() & KUsers::Cap_Samba) && samba ) ||
+       ( (kug->getUsers().getCaps() & KUsers::Cap_BSD) && posix ) ) {
 
     switch ( cbexpire->state() ) {
       case QButton::NoChange:
@@ -720,6 +815,8 @@ void propdlg::mergeUser( KUser *user, KUser *newuser )
           user->getExpire() : lesexpire->dateTime().toTime_t() );
         break;
     }
+  } else {
+    newuser->setExpire( -1 );
   }
 
   if ( !primaryGroup.isEmpty() ) {
@@ -779,13 +876,14 @@ bool propdlg::checkShell(const QString &shell)
 bool propdlg::check()
 {
   bool one = ( mUsers.getFirst() == mUsers.getLast() );
-  
-  if ( one && leid->text().isEmpty() ) {
+  bool posix = !( kug->getUsers().getCaps() & KUsers::Cap_Disable_POSIX ) || !( cbposix->isChecked() );
+
+  if ( one && posix && leid->text().isEmpty() ) {
     KMessageBox::sorry( 0, i18n("You need to specify an UID.") );
     return false;
   }
 
-  if ( one && lehome->text().isEmpty() ) {
+  if ( one && posix && lehome->text().isEmpty() ) {
     KMessageBox::sorry( 0, i18n("You must specify a home directory.") );
     return false;
   }
@@ -798,7 +896,7 @@ bool propdlg::check()
   }
 
   if ( kug->getUsers().getCaps() & KUsers::Cap_Samba ) {
-    if ( one && lerid->text().isEmpty() ) {
+    if ( one && lerid->text().isEmpty() && !( cbsamba->isChecked() ) ) {
       KMessageBox::sorry( 0, i18n("You need to specify a samba RID.") );
       return false;
     }
@@ -818,6 +916,7 @@ void propdlg::setpwd()
     QDateTime datetime;
     datetime.setTime_t( lstchg );
     leslstchg->setText( KGlobal::locale()->formatDateTime( datetime, false ) );
+    cbdisabled->setChecked( false );
   }
 }
 
@@ -827,12 +926,13 @@ void propdlg::slotOk()
     reject();
     return;
   }
-  
+
   bool one = ( mUsers.getFirst() == mUsers.getLast() );
 
   uid_t newuid = leid->text().toULong();
 
-  if ( one && olduid != newuid )
+  if ( one && ( !( kug->getUsers().getCaps() & KUsers::Cap_Disable_POSIX ) || !cbposix->isChecked() )
+               && olduid != newuid )
   {
     if (kug->getUsers().lookup(newuid)) {
       KMessageBox::sorry( 0,
@@ -841,9 +941,9 @@ void propdlg::slotOk()
     }
   }
 
-  if ( kug->getUsers().getCaps() & KUsers::Cap_Samba ) {
+  if ( one && ( kug->getUsers().getCaps() & KUsers::Cap_Samba ) && !cbsamba->isChecked() ) {
     uint newrid = lerid->text().toInt();
-    if ( one && oldrid != newrid ) {
+    if ( oldrid != newrid ) {
       if (kug->getUsers().lookup_sam(newrid)) {
         KMessageBox::sorry( 0,
           i18n("User with RID %1 already exists").arg(newrid) );
